// This file may be redistributed and modified only under the terms of
// the GNU Lesser General Public License (See COPYING for details).
// Copyright (C) 2003 Alistair Riddoch

// $Id$

#include <Atlas/Objects/SmartPtr.h>

#include <Atlas/Message/Element.h>

namespace Atlas { namespace Objects {

NullSmartPtrDereference::~NullSmartPtrDereference()
{
}

} } // namespace Atlas::Objects
